@@ -1,5 +1,5 @@
 from abc import abstractmethod
-from typing import List
+from typing import List, Any
 from pydantic import BaseSettings
 
 from obsei.payload import TextPayload
@@ -17,7 +17,7 @@ class BaseTextPreprocessor(BaseSettings):
 
     @abstractmethod
     def preprocess_input(
-        self, input_list: List[TextPayload], config: BaseTextProcessorConfig, **kwargs
+        self, input_list: List[TextPayload], config: BaseTextProcessorConfig, **kwargs: Any
     ) -> List[TextPayload]:
         pass
 
