@@ -1,5 +1,5 @@
 from copy import deepcopy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 from elasticsearch import Elasticsearch
 from elasticsearch.helpers import bulk
@@ -14,29 +14,26 @@ class ElasticSearchSinkConfig(BaseSinkConfig):
     # This is done to avoid exposing member to API response
     _es_client: Elasticsearch = PrivateAttr()
     TYPE: str = "Elasticsearch"
-    host: str
-    port: int
+    hosts: Union[str, List[str], None]
     index_name: str = "es_index"
     username: SecretStr = Field(SecretStr(""), env="elasticsearch_username")
     password: SecretStr = Field(SecretStr(""), env="elasticsearch_password")
-    scheme: str = "http"
-    ca_certs: bool = False
-    verify_certs: bool = True
+    ca_certs: str = Field("<DEFAULT>")
+    verify_certs: bool = False
     create_index: bool = True
     timeout = 30
-    custom_mapping: Optional[dict] = None
+    custom_mapping: Optional[Dict[str, Any]] = None
     refresh_type: str = "wait_for"
     base_payload: Optional[Dict[str, Any]] = None
 
     def __init__(self, **data: Any):
         super().__init__(**data)
         self._es_client = Elasticsearch(
-            hosts=[{"host": self.host, "port": self.port}],
+            hosts=self.hosts,
             http_auth=(
                 self.username.get_secret_value(),
                 self.password.get_secret_value(),
             ),
-            scheme=self.scheme,
             ca_certs=self.ca_certs,
             verify_certs=self.verify_certs,
             timeout=self.timeout,
@@ -48,7 +45,7 @@ class ElasticSearchSinkConfig(BaseSinkConfig):
         if self.create_index:
             self._create_index(self.index_name)
 
-    def _create_index(self, index_name):
+    def _create_index(self, index_name: str) -> None:
         if self.custom_mapping:
             mapping = self.custom_mapping
         else:
@@ -67,7 +64,7 @@ class ElasticSearchSinkConfig(BaseSinkConfig):
             }
 
         try:
-            self._es_client.indices.create(index=index_name, body=mapping)
+            self._es_client.indices.create(index=index_name, mappings=mapping)
         except RequestError as e:
             # With multiple workers we need to avoid race conditions, where:
             # - there's no index in the beginning
@@ -76,7 +73,7 @@ class ElasticSearchSinkConfig(BaseSinkConfig):
             if not self._es_client.indices.exists(index=index_name):
                 raise e
 
-    def bulk(self, payloads):
+    def bulk(self, payloads: List[Dict[str, Any]]) -> Any:
         return bulk(
             self._es_client, payloads, request_timeout=300, refresh=self.refresh_type
         )
@@ -90,8 +87,8 @@ class ElasticSearchSink(BaseSink):
         self,
         analyzer_responses: List[TextPayload],
         config: ElasticSearchSinkConfig,
-        **kwargs
-    ):
+        **kwargs: Any
+    ) -> Any:
 
         payloads = []
         for analyzer_response in analyzer_responses:
