@@ -24,8 +24,8 @@ class HttpSink(BaseSink):
         super().__init__(convertor=convertor, **data)
 
     def send_data(  # type: ignore[override]
-        self, analyzer_responses: List[TextPayload], config: HttpSinkConfig, **kwargs
-    ):
+        self, analyzer_responses: List[TextPayload], config: HttpSinkConfig, **kwargs: Any
+    ) -> Any:
 
         headers = config.headers or DEFAULT_HEADERS
 
